=begin
2010 (c) TIG

Put this file 'axo+iso.rb' into your Sketchup Plugins folder and restart
Sketchup - the tools are available in any SKP thereafter...

Usage: type the desired option in Ruby Console xxxxxxx + <enter> ***

Available options are:

axo3060    which sets the camera to a 30/60 axonometric view and zooms extents
axo6030    which sets the camera to a 60/30 axonometric view and zooms extents
axo4545    which sets the camera to a 45/45 axonometric view and zooms extents
iso3030    which sets the camera to a 30/60 isometric view and zooms extents

The current view changes to the axo/iso format desired and model-extents 
are zoomed, now zoom in/out and pan BUT DON'T orbit - that would loose the 
axo/iso-ness; then save that view to a Scene-tab.

If you have 3d axo it needs 'distorting' so that it prints or exports as an 
image and looks correct.  The whole model needs scaling - particularly in 
the Z axis.  There are two tools to do this for you.  Use with care and 
remember to undo the temporary scaling to continue modeling.
After setting an axo view type in the Ruby Console + <enter>:

axo_scale

to scale the whole model, so it is distorted but looks correct.

axo_restore_scale

to rescale the whole model back to as it was.

***You could make a menu or toolbar to do this BUT since it's only used 
occasionally then typing it into the Ruby Console is maybe easiest...

Version:
1.0 20100616 First release with four options.
1.1 20100616 Glitch on Axo6030 'up' fixed.
1.2 20101117 Added axo_scale option.
2.0 20161230 Usage now TIG.axo4545 etc, optional -1 argument = view from below.

=end
###
require 'sketchup.rb'
module TIG
	###
	def self.axo3060(i=1)
		i=1 unless i==-1
		model=Sketchup.active_model
		model.start_operation("axo3060")
		view=model.active_view
		camera=view.camera
		eye=Geom::Point3d.new(-25.3259,-5.00502,i*463.851)
		target=Geom::Point3d.new(10.9614,15.9032,41.225)
		up=Geom::Vector3d.new(0.862238,0.496811,0.0986113)
		perspective=false
		newcamera=Sketchup::Camera.new(eye,target,up,perspective)
		view.camera=newcamera
		Sketchup.send_action("viewZoomExtents:")
		puts
		model.commit_operation
	end
	###
	def self.axo6030(i=1)
		i=1 unless i==-1
		model=Sketchup.active_model
		model.start_operation("axo6030")
		view=model.active_view
		camera=view.camera
		eye=Geom::Point3d.new(15.016, 7.62608, i*163.506)
		target=Geom::Point3d.new(22.5294, 20.6242, 25.1643)
		up=Geom::Vector3d.new(0.497526, 0.860713, 0.10789)
		perspective=false
		newcamera=Sketchup::Camera.new(eye,target,up,perspective)
		view.camera=newcamera
		Sketchup.send_action("viewZoomExtents:")
		puts
		model.commit_operation
	end
	###
	def self.axo4545(i=1)
		model=Sketchup.active_model
		i=1 unless i==-1
		model.start_operation("axo4545")
		view=model.active_view
		camera=view.camera
		eye=Geom::Point3d.new(4.74856, 4.7501, i*210.058)
		target=Geom::Point3d.new(19.685, 19.685, 19.685)
		up=Geom::Vector3d.new(0.70281, 0.70281, 0.110275)
		perspective=false
		newcamera=Sketchup::Camera.new(eye,target,up,perspective)
		view.camera=newcamera
		Sketchup.send_action("viewZoomExtents:")
		puts
		model.commit_operation
	end
	###
	def self.iso3030(i=1)
		model=Sketchup.active_model
		i=1 unless i==-1
		model.start_operation("iso3030")
		view=model.active_view
		camera=view.camera
		eye=Geom::Point3d.new(-219.18,-239.658,i*258.471)
		target=Geom::Point3d.new(72.869,52.1777,-23.5562)
		up=Geom::Vector3d.new(0.398992, 0.398701, 0.825738)
		perspective=false
		newcamera=Sketchup::Camera.new(eye,target,up,perspective)
		view.camera=newcamera
		Sketchup.send_action("viewZoomExtents:")
		puts
		model.commit_operation
	end
	###
	def self.axo_scale()
		model=Sketchup.active_model
		model.start_operation("axo_scale")
		UI.messagebox("Warning:\nThis will Scale the Model and\ndistort it so that it looks correct\nin AXO views.\nUse with care!\nTo Undo it use 'axo_scale_restore' later...")
		ents=model.entities
		tg=ents.add_group(ents.to_a)
		tr=Geom::Transformation.scaling(ORIGIN, 1.003053768, 1.003054401, 9.068228873)
		tg.transform!(tr)
		tg.explode
		model.commit_operation
	end
	###
	def self.axo_scale_restore()
		model=Sketchup.active_model
		model.start_operation("axo_scale_restore")
		UI.messagebox("Warning:\nThis will Scale the Model back from its 'axo_scale' values\nso that it is correct once again.\nIt will distort the Model if it is used otherwise - \nso use with care...")
		ents=model.entities
		tg=ents.add_group(ents.to_a)
		tr=Geom::Transformation.scaling(ORIGIN, 1.0/1.003053768, 1.0/1.003054401, 1.0/9.068228873)
		tg.transform!(tr)
		tg.explode
		model.commit_operation
	end
	###
end#TIG

